% RunAdpObs2GPSSimulation      Initializes and runs simulation for adaptive lever 
%                      arm estimation in for 2 GPS antennas on simulated GPS data 
% Author:              Svenn A. Tutturen
% Date:                July 2014 
%
%__________________________________________________________________________

clear all;
close all;
clc;




%% Initialization of constant matrices


%tstart = 150; %1006
tstart = 130; %1023

tsamp=0.02;    %Sampling time (NOT ODE solver time step)


%tstop = 270; %1006
tstop = 310; %1023
t_int = tstop - tstart;

%% Input of real data - rates and angles

datafile = 1023; 




if datafile == 1006
load('1006.mat')
elseif datafile == 1023
    load('1023.mat')
else error('enter valid datafile number')
    
end

n = (tstop-tstart)/tsamp;

time = (0:tsamp:tstop-tsamp)';

n_start = tstart/tsamp;
n_stop = tstop/tsamp - 1;


time = (tsamp:tsamp:t_int)';

signal  = ones(length(time),6);

nu = [time, signal];




nu(:,2) = 0.01*data(24,n_start:n_stop)'; %surge velocity
nu(:,3) = 0.01*data(25,n_start:n_stop)'; %sway velocity 
nu(:,4) = 0.01*data(7,n_start:n_stop)'-0.01*mean(data(7,n_start:n_stop)); %heave velocity

nu(:,5) = (pi/180) * data(11,n_start:n_stop)'; %roll rate
nu(:,6) = (pi/180) * data(12,n_start:n_stop)'; %pitch rate 
nu(:,7) = (pi/180) * data(13,n_start:n_stop)'; %yaw rate


signal2 = ones(length(time),3);
Theta = [time, signal2];



Theta(:,2) = (pi/180) * data(8,n_start:n_stop)'; %roll angle
Theta(:,3) = (pi/180) * data(9,n_start:n_stop)'; %pitch angle
Theta(:,4) = (pi/180) * data(10,n_start:n_stop)'; %yaw angle


%% offline removal of discontinuity only for 1006 and 1023:

if datafile == 1006
for i=1:n
if time(i) > 36 && Theta(i,4)<4
    Theta(i,4) = Theta(i,4) + 2*pi;
end
    if  time(i) > 96 && Theta(i,4)<8
     Theta(i,4) = Theta(i,4) + 2*pi;
    end
end
elseif datafile == 1023
    for i=1:n
if time(i) > 122 && Theta(i,4)<4
    Theta(i,4) = Theta(i,4) + 2*pi;
end
    if  time(i) >  270 && Theta(i,4)<9.2
     Theta(i,4) = Theta(i,4) + 2*pi;
    end
    end
end

%% Input of GPS data

signal3  = zeros(length(time),3);

y = [time, signal3];

l = [12 0.56 13]'*0;



%Down position
Dpos = zeros(1,length(time));
Dpos(1) = 0.21; %for 1023
for i=1:1:n-2
   Dpos(i+1) = Dpos(i) + nu(i,4)*0.02;  
    
end

Dpos = data(4,n_start:n_stop)*0.01;


y(:,2) = data(48,n_start:n_stop)'-data(48,n_start); %north position
y(:,3) = data(49,n_start:n_stop)'-data(49,n_start); %east position
y(:,4) = Dpos; %down position







for i=1:1:n
             
h = 0;
[N(i),E(i),D(i)] = llh2ecef(data(2,i+n_start)*pi/180,data(3,i+n_start)*pi/180,h);
end
jj = y(1,2); %for plot below
value_checks = 0; %to verifi that the input data is correct
if value_checks == 1
    figure(11)
subplot(2,1,1)
plot(y(:,3),y(:,2))
subplot(2,1,2)
plot(nu(:,7),'r')

%
figure(10)
subplot(2,1,1)
plot(y(:,2)-y(1,2))
hold on
plot(-N+N(1),'r')
plot(yplot(:,1),'g')
subplot(2,1,2)
plot(N-N(1),'r')
%}


end


%% Adding lever arms


%figure(10)
%hold on;
%subplot(2,1,1)
%plot((y(:,2)-jj ),'r')
%subplot(2,1,2)
%plot(nu(:,2),'r')



%{


for i = 1:n_high_fid-0.01
    
    [J,J11,J22] = eulerang(phi,theta,psi);
    
  Omega_dot = J22*nu(i,5:7)';
  Theta(i+1,2:4) = Theta(i,2:4) + 0.01*Omega_dot';
 % Theta(i+1,3) = Theta(i,3) + 0.01*nu(i,6);
 % Theta(i+1,4) = Theta(i,4) + 0.01*nu(i,7);


end
%}




%% Down position




%{
figure(2)
plot(time,Dpos);
hold on;

figure(3)
plot(time,y(:,2));
hold on;


figure(5)
plot(time,y(:,3));
hold on;

%}


%y(:,2) = N-N(1);
%y(:,3) = E-E(1);


%%INTERPOLATION

Nx = 1:20:t_int*50;
Nxq = 1:1:t_int*50;

Nv = y(Nx,2);

Nvq2 = interp1(Nx,Nv,Nxq,'spline');
%{
figure(100)
plot(Nx,Nv,'--',Nxq,Nvq2);
hold on
title('Spline Interpolation');
%}


Ex = 1:20:t_int*50;
Exq = 1:1:t_int*50;

Ev = y(Ex,3);

Evq2 = interp1(Ex,Ev,Exq,'spline');
%{
figure(2)
plot(Ex,Ev,'--',Exq,Evq2);
hold on
title('Spline Interpolation');
%}



Rollx = 1:20:t_int*50;
Rollxq = 1:1:t_int*50;

Rollv = Theta(Rollx,2);

Rollvq2 = interp1(Rollx,Rollv,Rollxq,'spline');
%{
figure(4)
plot(Rollx,Rollv,'--',Rollxq,Rollvq2);
title('Spline Interpolation');
%}

pitchx = 1:20:t_int*50;
pitchxq = 1:1:t_int*50;

pitchv = Theta(pitchx,3);

pitchvq2 = interp1(pitchx,pitchv,pitchxq,'spline');
%{
figure(5)
plot(pitchx,pitchv,'--',pitchxq,pitchvq2);
title('Spline Interpolation');
%}


yawx = 1:1:t_int*50;
yawxq = 1:1:t_int*50;

yawv = Theta(yawx,4);
yawvq2 = interp1(yawx,yawv,yawxq,'spline');
%{
figure(6)
plot(yawx,yawv,'--',yawxq,yawvq2);
title('Spline Interpolation');
%}

%{
figure(99)
plot(N-N(1))
%}


%y(:,2) = Nvq2';
%y(:,3) = Evq2';
%y(:,4) = D;

%y(:,2) = -N+N(1);
%y(:,3) = -E+E(1);
%y(:,4) = D-D(1);


%Theta(:,2) = Rollvq2';
%Theta(:,3) = pitchvq2';
%Theta(:,4) = yawvq2';


%{
figure(313)
plot(Dpos)
hold on;
%}

y(:,2) = y(:,2)-y(1,2);
y(:,3) = y(:,3)-y(1,3);
%y(:,4) = y(:,4)-y(1,4);
%% Initial conditions

x10 = y(1,2)*1;

x20 = y(1,3)*1 ;

x30 = y(1,4)*1;

%lever arm initializations
x40 = 1;

x50 = 0.3;

x60= -13;

x70 = -0.5;

x80 = 0.9;

x90 = -14;

P0x0 = 0;
P0y0 = 0;
P0z0 = 0;
phi0 = Theta(1,2);
theta0 = Theta(1,3);
psi0 = Theta(1,4);


%% Run simulation



sim Adp2GPSSimulation.slx

%% Plot results

PlotAdpObs2GPSSimulation