% RunLObs1GPSExperimental      Initializes and runs simulation for Luenberger lever 
%                      arm estimation in for 1 GPS antenna on recorded GPS data 
% Author:              Svenn A. Tutturen
% Date:                July 2014
% Revisions: 
%
%__________________________________________________________________________

%clear all;
close all;
clc;




%% Initialization of constant matrices


tstart = 130; %1023

tsamp=0.02;    %Sampling time (NOT ODE solver time step)



tstop = 490; %1023
t_int = tstop - tstart;

%% Input of real data - rates and angles

datafile = 1023; 





if datafile == 1023
    load('1023.mat')
else error('enter valid datafile number')
    
end

n = (tstop-tstart)/tsamp;



n_start = tstart/tsamp;
n_stop = tstop/tsamp - 1;


time = (tsamp:tsamp:t_int)';

signal  = ones(length(time),6);

nu = [time, signal];




nu(:,2) = 0.01*data(24,n_start:n_stop)'; %surge velocity
nu(:,3) = 0.01*data(25,n_start:n_stop)'; %sway velocity 
nu(:,4) = 0.01*data(7,n_start:n_stop)'-0.01*1*mean(data(7,n_start:n_stop)); %heave velocity



nu(:,5) = (pi/180) * data(11,n_start:n_stop)'; %roll rate
nu(:,6) = (pi/180) * data(12,n_start:n_stop)'; %pitch rate 
nu(:,7) = (pi/180) * data(13,n_start:n_stop)'; %yaw rate


signal2 = ones(length(time),3);
Theta = [time, signal2];



Theta(:,2) = (pi/180) * data(8,n_start:n_stop)'; %roll angle
Theta(:,3) = (pi/180) * data(9,n_start:n_stop)'; %pitch angle
Theta(:,4) = (pi/180) * data(10,n_start:n_stop)'; %yaw angle


%% offline removal of discontinuity only for 1006 and 1023:

if datafile == 1023
    for i=1:n
if time(i) > 122 && Theta(i,4)<4
    Theta(i,4) = Theta(i,4) + 2*pi;
end
    if  time(i) >  270 && Theta(i,4)<9.2
     Theta(i,4) = Theta(i,4) + 2*pi;
    end
    end
end

%% Input of GPS data

signal3  = zeros(length(time),3);

y = [time, signal3];

l = [12 0.56 13]'*0;



%Down position
Dpos = zeros(1,length(time));
Dpos(1) = 0.21; %for 1023
for i=1:1:n-2
   Dpos(i+1) = Dpos(i) + nu(i,4)*0.02;  
    
end

Dpos = data(4,n_start:n_stop)*0.01-mean(data(4,n_start:n_stop));


y(:,2) = data(48,n_start:n_stop)'-data(48,n_start); %north position
y(:,3) = data(49,n_start:n_stop)'-data(49,n_start); %east position
y(:,4) = Dpos; %down position








y(:,2) = y(:,2)-y(1,2);
y(:,3) = y(:,3)-y(1,3);
y(:,4) = y(:,4)-y(1,4);
%% Initial conditions

x10 = y(1,2) + 0;
x20 = y(1,3) + 0 ;
x30 = y(1,4) + 0;






%Initial conditions for real data with no added lever arm:
%
x40 = 3;
x50 = 2;
x60=  -3;
%}



P0x0 = y(1,2);
P0y0 = y(1,3);
P0z0 = y(1,4);
phi0 = Theta(1,2);
theta0 = Theta(1,3);
psi0 = Theta(1,4);


%% Run simulation



sim LObs1GPSExperimental

%% Plot results

PlotLObsExperimental