% Run      Initializes and runs simulation for Luenberger lever 
%                      arm estimation in for 2 GPS antenna on recorded MRU data 
% Author:              Svenn A. Tutturen
% Date:                July 2014
% Revisions: 
%
%__________________________________________________________________________

clear all;
close all;
clc;


tstart = .01; 
tsamp = 0.01;
tstop = 150;



%% Input of real data - rates and angles

datafile = 3034; %3032, 3033 or 3034, or 3015




if datafile == 3034
load('GU_data_test3034.mat')

load('3034_VMM.mat')

n_d = 0;

else error('enter valid datafile number')
end


n_start = tstart/tsamp;
n = (tstop-tstart)/tsamp;
n_stop = tstop/tsamp;

time = (tstart:tsamp:tstop)';













signal  = ones(length(time),6);

nu = [time, signal];


nu(:,2) = GU_data(25,n_start:n_stop-n_d);%surge velocity
nu(:,3) = GU_data(26,n_start:n_stop-n_d); %sway velocity 
nu(:,4) = GU_data(8,n_start:n_stop-n_d); %heave velocity (approx 0)
nu(:,5) = VMM_data(6,n_start+n_d:n_stop)*pi/180;% p
nu(:,6) = VMM_data(7,n_start+n_d:n_stop)*pi/180; % q
nu(:,7) = VMM_data(8,n_start+n_d:n_stop)*pi/180; % r





signal2 = ones(length(time),3);
Theta = [time, signal2];




Theta(:,2) = (pi/180) * GU_data(9,n_start:n_stop-n_d); %roll angle
Theta(:,3) = (pi/180) * GU_data(10,n_start:n_stop-n_d); %pitch angle 
Theta(:,4) = (pi/180) * GU_data(11,n_start:n_stop-n_d); %yaw angle



for i=1:n
if Theta(i,4)<6.01
    Theta(i,4) = Theta(i,4) + 2*pi;
elseif time(i) > 140 && Theta(i,4) <12
    Theta(i,4) = Theta(i,4) + 2*pi;
end
    
end


%% If S_dot is measured



signal5  = ones(length(time),3);


omegadot_true = [time, signal5];

omegadot_true(:,2) = VMM_data(30,n_start+n_d:n_stop);% pdot

omegadot_true(:,3) = VMM_data(31,n_start+n_d:n_stop); % qdot

omegadot_true(:,4) = VMM_data(32,n_start+n_d:n_stop); % rdot



%% if nudot is measured (assuming A0 = nudot)

signal5  = ones(length(time),3);

nudot = [time, signal5];

nudot(:,2) = VMM_data(27,n_start+n_d:n_stop);% udot
nudot(:,3) = VMM_data(28,n_start+n_d:n_stop); % vdot
nudot(:,4) = VMM_data(29,n_start+n_d:n_stop); % wdot


%% Input of GPS data

signal3  = zeros(length(time),9);

y = [time, signal3];


bias_CO_heave = ones(1,length(time))*mean(VMM_data(29,n_start+n_d:n_stop))*1;


bias_MRU1_heave = ones(1,length(time))*mean(VMM_data(5,n_start+n_d:n_stop))*1;

bias_MRU2_heave = ones(1,length(time))*mean(VMM_data(11,n_start+n_d:n_stop))*1;

y(:,2) = VMM_data(27,n_start+n_d:n_stop); %surge acceleration A0
y(:,3) = VMM_data(28,n_start+n_d:n_stop);
y(:,4) = (VMM_data(29,n_start+n_d:n_stop)-bias_CO_heave);
y(:,5) = VMM_data(3,n_start+n_d:n_stop); %surge acceleration A1
y(:,6) = VMM_data(4,n_start+n_d:n_stop);
y(:,7) = (VMM_data(5,n_start+n_d:n_stop)-bias_MRU1_heave);
y(:,8) = VMM_data(9,n_start+n_d:n_stop); %surge acceleration A1
y(:,9) = VMM_data(10,n_start+n_d:n_stop);
y(:,10) = (VMM_data(11,n_start+n_d:n_stop)-bias_MRU2_heave);











Rot = Rzyx(Theta(1,2),Theta(1,3),Theta(1,4));

A0 = Rot*y(1,2:4)';


x10 = A0(1);
x20 = A0(2);
x30 = A0(3);


%initial conditions used for real data:
k = 0;
x40 = 0.358*k +30;
x50  = 0.804*k -30;
x60 = -4.321*k -30;
x70 = 14.978*k +30;
x80 = 0.039*k +30;
x90 = .568*k +30;



A0x0 = A0(1); 
A0y0 = A0(2);
A0z0 = A0(3);


phi0 = Theta(1,2);
theta0 = Theta(1,3);
psi0 = Theta(1,4);



%% Run simulation

sim MRULObs2MRUsExperimental
%% Plot results

PlotMRULObs2MRUsExperimental