close all;
hold on
d = simout.signals.values;





%x_cont: x-continuous ran at the previous run without jumps
%t_cont: simout.time for run without jumps

%initialization of continous parameters (copy into matlab workspace after first run)
%{

x_cont = x;
t_cont = t;
d_cont = simout.signals.values;

%for plotting the hybrid simulation without red lines: (copy this into matlab workspace after
second run (hybrid))

x_h = x;
t_h = t;
d_h = simout.signals.values;

%}

%

V = zeros(1,length(x(:,1))); %Lyapunov function (for plots)

M = diag([450,450,100]);
K_i = diag([10,10,5]);
for i = 1:length(x(:,1))
    
x1 = x(i,1:3)';    
x2 = x(i,4:6)';    
x3 = (d(i)-x(i,7:9))';



V(i) = 0.5*(x1'*x1 + x2'*M*x2 + x3'/K_i*x3);

end


scrsz = get(0,'ScreenSize');


%% POSITION ERROR
%
fig1 = figure('Position',[400 250 scrsz(3)/1.75 scrsz(4)/1.75]);


clf
subplot(3,1,1)
plot(t,x_h(:,1))
hold on
plot(t_cont,x_cont(:,1),'g')
grid on
ylabel('Position error [m]')
xlabel('Time [s]')
title('Position error, p_1 (N).  With jumping (blue) and without (green) ')
subplot(3,1,2)
plot(t,x_h(:,2))
hold on
plot(t_cont,x_cont(:,2),'g')
grid on
ylabel('Position error [m]')
xlabel('Time [s]')
title('Position error, p_2 (E).  With jumping (blue) and without (green) ')
subplot(3,1,3)
plot(t,x_h(:,3))
hold on
plot(t_cont,x_cont(:,3),'g')
grid on
ylabel('Position error [rad]')
xlabel('Time [s]')
title('Position error, p_3 (Heading).  With jumping (blue) and without (green) ')

print -depsc PositionErrorHybridDP.eps


%% VELOCITY ERROR

fig2 = figure('Position',[400 250 scrsz(3)/1.75 scrsz(4)/1.75]);


clf
subplot(3,1,1)
plot(t,x_h(:,4))
hold on
plot(t_cont,x_cont(:,4),'g')
grid on
ylabel('Velocity error [m/s]')
xlabel('Time [s]')
title('Velocity, v_1 (N).  With jumping (blue) and without (green) ')
subplot(3,1,2)
plot(t,x_h(:,5))
hold on
plot(t_cont,x_cont(:,5),'g')
grid on
ylabel('Position error [m]')
xlabel('Time [s]')
title('Velocity error, v_2 (E).  With jumping (blue) and without (green) ')
subplot(3,1,3)
plot(t,x_h(:,6))
hold on
plot(t_cont,x_cont(:,6),'g')
grid on
ylabel('Position error [rad/s]')
xlabel('Time [s]')
title('Velocity error, v_3 (Heading).  With jumping (blue) and without (green) ')

print -depsc VelocityErrorHybridDP.eps


%% INTEGRAL STATE ERROR

fig3 = figure('Position',[400 250 scrsz(3)/1.75 scrsz(4)/1.75]);


clf
subplot(3,1,1)
plot(t,d(:,1)-x_h(:,7))
hold on
plot(t_cont,d_cont(:,1)-x_cont(:,7),'g')
grid on
ylabel('Integral state error')
xlabel('Time [s]')
title('Integral state error, (N).  With jumping (blue) and without (green)  ')
subplot(3,1,2)
plot(t,d(:,2)-x_h(:,8))
hold on
plot(t_cont,d_cont(:,2)-x_cont(:,8),'g')
grid on
ylabel('Integral state error')
xlabel('Time [s]')
title('Integral state error, (E).  With jumping (blue) and without (green)  ')
subplot(3,1,3)
plot(t,d(:,3)-x_h(:,9))
hold on
plot(t_cont,d_cont(:,3)-x_cont(:,9),'g')
grid on
ylabel('Integral state error')
xlabel('Time [s]')
title('Integral state error (Heading).  With jumping (blue) and without (green)  ')

print -depsc IntegralErrorHybridDP.eps
%

%% LYAPUNOV FUNCTION + CLOSE UP OF INTEGRAL STATE ERROR

fig4 = figure('Position',[400 250 scrsz(3)/1.75 scrsz(4)/1.75]);

n_start = 8800;
n_stop = 16000;


clf
subplot(2,1,1)
plotflows(t(n_start:n_stop),j(n_start:n_stop),d(n_start:n_stop,1)-x(n_start:n_stop,7))
hold on
%plot(t_cont(12000:16000),d_cont(12000:16000,1)-x_cont(12000:16000,7),'g')
grid on
ylabel('Integral state error')
xlabel('Time [s]')
title('Integral state error, (N) - Zoom.  With jumping - red lines indicate jumps ')
subplot(2,1,2)
plotflows(t(n_start:n_stop),j(n_start:n_stop),V(n_start:n_stop))

grid on
ylabel('Lyapunov function')
xlabel('Time [s]')
title('Lyapunov function value for the hybrid solution - red lines indicate jumps')


print -depsc LyapunovandJumpZoomHybridDP.eps

%}